==> prebid-mobile-sdk-core-2.0.0-sources.jar: org/prebid/mobile/rendering/bidding/interfaces/StandaloneInterstitialEventHandler.java <==
/*
 *    Copyright 2018-2021 Prebid.org, Inc.
 *
 *    Licensed under the Apache License, Version 2.0 (the "License");
 *    you may not use this file except in compliance with the License.
 *    You may obtain a copy of the License at
 *
 *        http://www.apache.org/licenses/LICENSE-2.0
 *
 *    Unless required by applicable law or agreed to in writing, software
 *    distributed under the License is distributed on an "AS IS" BASIS,
 *    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *    See the License for the specific language governing permissions and
 *    limitations under the License.
 */

package org.prebid.mobile.rendering.bidding.interfaces;

import androidx.annotation.Nullable;
import org.prebid.mobile.rendering.bidding.data.bid.Bid;
import org.prebid.mobile.rendering.bidding.listeners.InterstitialEventListener;

public class StandaloneInterstitialEventHandler implements InterstitialEventHandler {

    private InterstitialEventListener mInterstitialEventListener;

    @Override
    public void setInterstitialEventListener(InterstitialEventListener interstitialEventListener) {
        mInterstitialEventListener = interstitialEventListener;
    }

    @Override
    public void requestAdWithBid(
            @Nullable Bid bid
    ) {
        mInterstitialEventListener.onPrebidSdkWin();
    }

    @Override
    public void show() {

    }

    @Override
    public void trackImpression() {

    }

    @Override
    public void destroy() {

    }

}

==> prebid-mobile-sdk-core-2.1.1-sources.jar: org/prebid/mobile/rendering/bidding/interfaces/StandaloneInterstitialEventHandler.java <==
/*
 *    Copyright 2018-2021 Prebid.org, Inc.
 *
 *    Licensed under the Apache License, Version 2.0 (the "License");
 *    you may not use this file except in compliance with the License.
 *    You may obtain a copy of the License at
 *
 *        http://www.apache.org/licenses/LICENSE-2.0
 *
 *    Unless required by applicable law or agreed to in writing, software
 *    distributed under the License is distributed on an "AS IS" BASIS,
 *    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *    See the License for the specific language governing permissions and
 *    limitations under the License.
 */

package org.prebid.mobile.rendering.bidding.interfaces;

import androidx.annotation.Nullable;

import org.prebid.mobile.rendering.bidding.data.bid.Bid;
import org.prebid.mobile.rendering.bidding.listeners.InterstitialEventListener;

public class StandaloneInterstitialEventHandler implements InterstitialEventHandler {

    @Nullable
    private InterstitialEventListener interstitialEventListener;

    @Override
    public void setInterstitialEventListener(InterstitialEventListener interstitialEventListener) {
        this.interstitialEventListener = interstitialEventListener;
    }

    @Override
    public void requestAdWithBid(
            @Nullable Bid bid
    ) {
        if (interstitialEventListener != null) {
            interstitialEventListener.onPrebidSdkWin();
        }
    }

    @Override
    public void show() {

    }

    @Override
    public void trackImpression() {

    }

    @Override
    public void destroy() {
        interstitialEventListener = null;
    }

}
